seqtools.replace_sequence_elements_cyclically_with_new_material
===============================================================

.. autofunction:: abjad.tools.seqtools.replace_sequence_elements_cyclically_with_new_material
